@@ -1039,7 +1039,7 @@ rep.rows <- function (mat, times)
 #' 
 #' @noRd
 # Test: Bootstrapped Network Statistics
-# Updated 26.04.2021
+# Updated 16.08.2021
 boot.one.test <- function (bootSemNeT.obj,
                            test = c("ANCOVA", "ANOVA", "t-test"),
                            measures = c("ASPL", "CC", "Q"),
@@ -1211,7 +1211,11 @@ boot.one.test <- function (bootSemNeT.obj,
       aov.test <- aov(as.formula(aov.formula), data = aov.obj)
       
       #ANCOVA
-      acov.test <- car::Anova(aov.test, type = "III")
+      if(ncol(groups) > 1){
+        acov.test <- car::Anova(aov.test, type = "III")
+      }else{
+        acov.test <- car::Anova(aov.test, type = "II")
+      }
       
       #Tidy ANCOVA
       tidy.acov <- as.data.frame(broom::tidy(acov.test), stringsAsFactors = FALSE)
@@ -1247,7 +1251,7 @@ boot.one.test <- function (bootSemNeT.obj,
         if(ncol(groups) == 1){
           tests[[paste(measures[i])]]$HSD <- suppressWarnings(TukeyHSD(aov.test))$Group
         }else{
-          tests[[paste(measures[i])]]$HSD <- unlist(suppressWarnings(TukeyHSD(aov.test)), recursive = FALSE)
+          tests[[paste(measures[i])]]$HSD <- suppressWarnings(TukeyHSD(aov.test))
         }
         
       }
